"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleRouteNotFound = exports.handleOtherErrors = exports.handleHttpErrors = void 0;
const exceptions_1 = require("../exceptions");
/**
 * @param {HttpException | e.Request} err
 * @param {e.Request | e.Response} req
 * @param {e.Response | e.NextFunction} res
 * @param next
 * @return {any}
 */
const handleHttpErrors = (err, req, res, next) => {
    if (!(err instanceof exceptions_1.HttpException))
        return next();
    const { message, status, textStatus } = err;
    const response = {
        response: null,
        status: {
            code: status,
            text: textStatus,
            message: message
        }
    };
    return res.status(status).json(response);
};
exports.handleHttpErrors = handleHttpErrors;
/**
 * @param err
 * @param {e.Request} req
 * @param {e.Response} res
 * @param {e.NextFunction} next
 */
const handleOtherErrors = (err, req, res, next) => {
    const internalEx = new exceptions_1.InternalServerErrorException(), response = {
        status: {
            code: internalEx.status,
            text: internalEx.textStatus,
            message: internalEx.message
        }
    };
    res.status(internalEx.status).json(response);
};
exports.handleOtherErrors = handleOtherErrors;
/**
 * @param {e.Request | e.Response} req
 * @param {e.Response | e.NextFunction} res
 */
const handleRouteNotFound = (req, res) => {
    const notFoundEx = new exceptions_1.NotFoundException(), response = {
        status: {
            code: notFoundEx.status,
            text: notFoundEx.textStatus,
            message: notFoundEx.message
        }
    };
    res.status(notFoundEx.status).json(response);
};
exports.handleRouteNotFound = handleRouteNotFound;
