import {TResponse} from './TResponse';
import {HttpStatus} from './HttpStatus';
import {HttpException} from './exceptions';

export class Response{

    /**
     * @param {T} data
     * @return {TResponse<T>}
     */
    public static success<T extends any = any>(data?: T): TResponse<T>{
        return {
            status: {
                code: HttpStatus.Ok,
                text: 'Ok',
                message: 'Ok'
            },
            response: data
        };
    }

    /**
     * @param {HttpException} error
     * @return {TResponse<null>}
     */
    public static error(error: HttpException): TResponse<null>;
    /**
     * @param {number} code
     * @param {string} [text]
     * @param {string} [message]
     * @return {TResponse<null>}
     */
    public static error(code: number, text?: string, message?: string): TResponse<null>;
    /**
     * @param {number | HttpException} errorOrCode
     * @param {string} [text]
     * @param {string} [message]
     * @return {TResponse<null>}
     */
    public static error(errorOrCode: number|HttpException, text?: string, message?: string): TResponse<null>{
        return {
            status: {
                code: typeof errorOrCode === 'number' ? errorOrCode : errorOrCode.status,
                text: typeof errorOrCode !== 'number' ? errorOrCode.textStatus : text || '',
                message: message ? message : (typeof errorOrCode !== 'number' ? errorOrCode.message : '')
            }
        } as TResponse<null>;
    }

}
