import {TMiddleware} from '../TMiddleware';
import {NextFunction, Request, Response} from 'express';
import {HttpException, InternalServerErrorException, NotFoundException} from '../exceptions';
import {TResponse} from '../TResponse';

/**
 * @param {HttpException | e.Request} err
 * @param {e.Request | e.Response} req
 * @param {e.Response | e.NextFunction} res
 * @param next
 * @return {any}
 */
export const handleHttpErrors: TMiddleware<HttpException> = (err, req: Request, res: Response, next: NextFunction) => {
    if(!(err instanceof HttpException))
        return next();

    const {message, status, textStatus} = err;
    const response: TResponse<null> = {
        response: null,
        status: {
            code: status,
            text: textStatus,
            message: message
        }
    };

    return res.status(status).json(response);
};

/**
 * @param err
 * @param {e.Request} req
 * @param {e.Response} res
 * @param {e.NextFunction} next
 */
export const handleOtherErrors: TMiddleware<any> = (err: any, req: Request, res: Response, next: NextFunction) => {
    const internalEx = new InternalServerErrorException(),
        response: TResponse<null> = {
            status: {
                code: internalEx.status,
                text: internalEx.textStatus,
                message: internalEx.message
            }
        };

    res.status(internalEx.status).json(response);
};

/**
 * @param {e.Request | e.Response} req
 * @param {e.Response | e.NextFunction} res
 */
export const handleRouteNotFound: TMiddleware = (req: Request, res: Response) => {
    const notFoundEx = new NotFoundException(),
        response: TResponse<null> = {
            status: {
                code: notFoundEx.status,
                text: notFoundEx.textStatus,
                message: notFoundEx.message
            }
        };

    res.status(notFoundEx.status).json(response);
};
