import {TResponse} from '../TResponse';
import {HttpException} from '../exceptions';

/**
 * @param {HttpException} error
 * @return {TResponse<never>}
 */
export function error(error: HttpException): TResponse<never>;
/**
 * @param {number} code
 * @param {string} [text]
 * @param {string} [message]
 * @return {TResponse<never>}
 */
export function error(code: number, text?: string, message?: string): TResponse<never>;
/**
 * @param {HttpException | number} errorOrCode
 * @param {string} [text]
 * @param {string} [message]
 * @return {TResponse<never>}
 */
export function error(errorOrCode: HttpException|number, text?: string, message?: string): TResponse<never>{
    return {
        status: {
            code: errorOrCode instanceof HttpException ? errorOrCode.status : errorOrCode,
            text: text ? text : (errorOrCode instanceof HttpException ? errorOrCode.textStatus : ''),
            message: message ? message : (errorOrCode instanceof HttpException ? errorOrCode.message : '')
        }
    };
}
